
.. image:: https://img.shields.io/github/workflow/status/equinor/fmu-tools/fmu-tools
    :target: https://github.com/equinor/fmu-tools/actions?query=workflow%3Afmu-tools

.. image:: https://img.shields.io/lgtm/alerts/g/equinor/fmu-tools.svg?logo=lgtm&logoWidth=18
    :target: https://lgtm.com/projects/g/equinor/fmu-tools/alerts/

.. image:: https://codecov.io/gh/equinor/fmu-tools/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/equinor/fmu-tools

.. image:: https://img.shields.io/lgtm/grade/python/g/equinor/fmu-tools.svg?logo=lgtm&logoWidth=18
    :target: https://lgtm.com/projects/g/equinor/fmu-tools/context:python

.. image:: https://img.shields.io/badge/python-3.6%20|%203.7%20|%203.8%20|%203.9-blue.svg
    :target: https://www.python.org

.. image:: https://img.shields.io/pypi/v/fmu-tools.svg
    :target: https://pypi.python.org/pypi/fmu-tools/


FMU tools is a Python library containing tools for pre and post processing
for FMU (Fast Model Update).

This library will contain various tools for automatic QC, setting up and analysing sensitivities,
and tools for visualization (coviz).

Documentation can be found on https://equinor.github.io/fmu-tools/.

This software is released under LGPLv3.

Copyright 2018-2021 Equinor ASA.
